@@ -1,6 +1,8 @@
 from __future__ import annotations
 
 import logging
+from dataclasses import asdict
+from functools import cached_property
 from typing import TYPE_CHECKING, Callable, TypedDict, final
 
 import mcu
@@ -21,7 +23,7 @@ from cartographer.adapters.klipper.mcu.constants import (
     KlipperCartographerConstants,
 )
 from cartographer.adapters.klipper.mcu.stream import KlipperStream, KlipperStreamMcu
-from cartographer.interfaces.printer import Mcu, Position, Sample
+from cartographer.interfaces.printer import CoilCalibrationReference, Mcu, Position, Sample
 
 if TYPE_CHECKING:
     from configfile import ConfigWrapper
@@ -50,6 +52,13 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
             raise RuntimeError(msg)
         return self._constants
 
+    @override
+    def get_coil_reference(self) -> CoilCalibrationReference:
+        return CoilCalibrationReference(
+            min_frequency=self.constants.count_to_frequency(self.constants.minimum_count),
+            min_frequency_temperature=self.constants.calculate_temperature(self.constants.minimum_adc_count),
+        )
+
     @property
     def commands(self) -> KlipperCartographerCommands:
         if self._commands is None:
@@ -57,14 +66,17 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
             raise RuntimeError(msg)
         return self._commands
 
+    @cached_property
+    def kinematics(self):
+        return self.printer.lookup_object("toolhead").get_kinematics()
+
     def __init__(
         self,
         config: ConfigWrapper,
-        smoothing_fn: Callable[[Sample], Sample] | None = None,
     ):
         self.printer = config.get_printer()
         self.klipper_mcu = mcu.get_printer_mcu(self.printer, config.get("mcu"))
-        self._stream = KlipperStream[Sample](self, self.klipper_mcu.get_printer().get_reactor(), smoothing_fn)
+        self._stream = KlipperStream[Sample](self, self.klipper_mcu.get_printer().get_reactor())
         self.dispatch = KlipperTriggerDispatch(self.klipper_mcu)
 
         self.motion_report = self.printer.load_object(config, "motion_report")
@@ -128,9 +140,14 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
     def start_session(self, start_condition: Callable[[Sample], bool] | None = None) -> Session[Sample]:
         return self._stream.start_session(start_condition)
 
+    @override
     def register_callback(self, callback: Callable[[Sample], None]) -> None:
         return self._stream.register_callback(callback)
 
+    @override
+    def unregister_callback(self, callback: Callable[[Sample], None]) -> None:
+        return self._stream.unregister_callback(callback)
+
     @override
     def start_streaming(self) -> None:
         self.commands.send_stream_state(enable=True)
@@ -139,6 +156,10 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
     def stop_streaming(self) -> None:
         self.commands.send_stream_state(enable=False)
 
+    @override
+    def get_current_time(self) -> float:
+        return self.printer.get_reactor().monotonic()
+
     def _set_threshold(self, trigger_frequency: float) -> None:
         trigger = self.constants.frequency_to_count(trigger_frequency)
         untrigger = self.constants.frequency_to_count(trigger_frequency * (1 - TRIGGER_HYSTERESIS))
@@ -146,8 +167,7 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
         self.commands.send_threshold(ThresholdCommand(trigger, untrigger))
 
     def _handle_mcu_identify(self) -> None:
-        kin = self.printer.lookup_object("toolhead").get_kinematics()
-        for stepper in kin.get_steppers():
+        for stepper in self.kinematics.get_steppers():
             if stepper.is_active_axis("z"):
                 self.dispatch.add_stepper(stepper)
 
@@ -164,9 +184,14 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
 
         frequency = self.constants.count_to_frequency(data["data"])
         temperature = self.constants.calculate_temperature(data["temp"])
-        position, velocity = self.get_requested_position(time)
+        position = self.get_requested_position(time)
 
-        sample = Sample(time=time, frequency=frequency, temperature=temperature, position=position, velocity=velocity)
+        sample = Sample(
+            time=time,
+            frequency=frequency,
+            temperature=temperature,
+            position=position,
+        )
         self._stream.add_item(sample)
 
     _data_error: str | None = None
@@ -177,7 +202,7 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
         if count == SHORTED_FREQUENCY_VALUE:
             error = "coil is shorted or not connected."
         elif count > self.constants.minimum_count * FREQUENCY_RANGE_PERCENT:
-            error = "coil frequency reading exceeded max expected value, received %(data)d"
+            error = "coil frequency reading exceeded max expected value, received %(count)d"
 
         if self._data_error == error:
             return
@@ -186,16 +211,22 @@ class KlipperCartographerMcu(Mcu, KlipperStreamMcu):
         if error is None:
             return
 
-        logger.error(error, {"data": data})
+        logger.debug(error, {"count": count})
         if len(self._stream.sessions) > 0:
-            self.klipper_mcu.get_printer().invoke_shutdown(error % {"data": data})
+            self.klipper_mcu.get_printer().invoke_shutdown(error % {"count": count})
 
-    def get_requested_position(self, time: float) -> tuple[Position | None, float | None]:
-        trapq = self.motion_report.trapqs.get("toolhead")
-        if trapq is None:
-            logger.warning("No dump trapq for toolhead, cannot get position at time %.3f", time)
-            return None, None
-        position, velocity = trapq.get_trapq_position(time)
-        if position is None:
-            return None, velocity
-        return Position(x=position[0], y=position[1], z=position[2]), velocity
+    def get_requested_position(self, time: float) -> Position | None:
+        kinematics = self.kinematics
+        stepper_pos = {
+            stepper.get_name(): stepper.mcu_to_commanded_position(stepper.get_past_mcu_position(time))
+            for stepper in kinematics.get_steppers()
+        }
+        position = kinematics.calc_position(stepper_pos)
+        return Position(x=position[0], y=position[1], z=position[2])
+
+    @override
+    def get_status(self, eventtime: float) -> dict[str, object]:
+        return {
+            "last_sample": asdict(self._stream.last_item) if self._stream.last_item else None,
+            "constants": self._constants.get_status() if self._constants else None,
+        }
