@@ -4,7 +4,7 @@ import logging
 from abc import ABC
 from functools import wraps
 from textwrap import dedent
-from typing import TYPE_CHECKING, Callable, Protocol, final
+from typing import TYPE_CHECKING, Callable, Protocol, Sequence, final
 
 from gcode import CommandError, GCodeCommand, GCodeDispatch
 from typing_extensions import override
@@ -20,7 +20,8 @@ from cartographer.runtime.integrator import Integrator
 if TYPE_CHECKING:
     from extras.homing import Homing
     from klippy import Printer
-    from stepper import PrinterRail
+    from mcu import MCU_endstop
+    from stepper import MCU_stepper
 
     from cartographer.adapters.klipper.configuration import KlipperConfiguration
     from cartographer.adapters.klipper.mcu import KlipperCartographerMcu
@@ -38,6 +39,11 @@ class KlipperLikeAdapters(Protocol):
     config: KlipperConfiguration
 
 
+class _Rail(Protocol):
+    def get_steppers(self) -> list[MCU_stepper]: ...
+    def get_endstops(self) -> list[tuple[MCU_endstop, str]]: ...
+
+
 class KlipperLikeIntegrator(Integrator, ABC):
     def __init__(self, adapters: KlipperLikeAdapters) -> None:
         self._config: KlipperConfiguration = adapters.config
@@ -72,13 +78,16 @@ class KlipperLikeIntegrator(Integrator, ABC):
         self._gcode.register_command(name, _catch_macro_errors(macro.run), desc=macro.description)
 
     @override
-    def register_temperature_sensor_factories(self) -> None:
-        self._printer.load_object(self._config.wrapper, "heaters").add_sensor_factory(
-            "cartographer_coil", PrinterTemperatureCoil
-        )
+    def register_coil_temperature_sensor(self) -> None:
+        pheaters = self._printer.load_object(self._config.wrapper, "heaters")
+        sensor = PrinterTemperatureCoil(self._mcu, self._config.coil)
+
+        object_name = f"temperature_sensor {sensor.name}"
+        self._printer.add_object(object_name, sensor)
+        pheaters.available_sensors.append(object_name)
 
     @reraise_as(CommandError)
-    def _handle_home_rails_end(self, homing: Homing, rails: list[PrinterRail]) -> None:
+    def _handle_home_rails_end(self, homing: Homing, rails: Sequence[_Rail]) -> None:
         homing_state = KlipperHomingState(homing)
         klipper_endstops = [
             es.endstop for rail in rails for es, _ in rail.get_endstops() if isinstance(es, KlipperEndstop)
