@@ -43,8 +43,8 @@ class ProbeAccuracyMacro(Macro):
     @override
     def run(self, params: MacroParams) -> None:
         lift_speed = params.get_float("LIFT_SPEED", 5.0, above=0)
-        retract = params.get_float("SAMPLE_RETRACT_DIST", 1.0, minval=0)
-        sample_count = params.get_int("SAMPLES", 10, minval=1)
+        retract = params.get_float("SAMPLE_RETRACT_DIST", default=1.0, minval=1.0)
+        sample_count = params.get_int("SAMPLES", default=10, minval=3)
         position = self._toolhead.get_position()
 
         logger.info(
@@ -74,11 +74,8 @@ class ProbeAccuracyMacro(Macro):
         std_dev = np.std(measurements)
 
         logger.info(
-            """
-            probe accuracy results:\n
-            maximum %.6f, minimum %.6f, range %.6f,
-            average %.6f, median %.6f, standard deviation %.6f
-            """,
+            "probe accuracy results:\n"
+            "maximum %.6f, minimum %.6f, range %.6f, average %.6f, median %.6f, standard deviation %.6f",
             max_value,
             min_value,
             range_value,
@@ -141,9 +138,8 @@ class ZOffsetApplyProbeMacro(Macro):
 
     def _log_offset_update(self, mode: str, model_name: str, new_offset: float) -> None:
         logger.info(
-            """cartographer: %s %s z_offset: %.3f
-            The SAVE_CONFIG command will update the printer config file
-            with the above and restart the printer.""",
+            "cartographer: %s %s z_offset: %.3f\n"
+            "The SAVE_CONFIG command will update the printer config file with the above and restart the printer.",
             mode,
             model_name,
             new_offset,
