@@ -1,12 +1,14 @@
 from __future__ import annotations
 
 import logging
+import math
+from random import random
 from typing import TYPE_CHECKING, final
 
 import numpy as np
 from typing_extensions import override
 
-from cartographer.interfaces.printer import HomingState, Macro, MacroParams
+from cartographer.interfaces.printer import Macro, MacroParams
 from cartographer.lib.statistics import compute_mad
 
 if TYPE_CHECKING:
@@ -43,8 +45,8 @@ class TouchAccuracyMacro(Macro):
     @override
     def run(self, params: MacroParams) -> None:
         lift_speed = params.get_float("LIFT_SPEED", 5.0, above=0)
-        retract = params.get_float("SAMPLE_RETRACT_DIST", 1.0, minval=0)
-        sample_count = params.get_int("SAMPLES", 5, minval=1)
+        retract = params.get_float("SAMPLE_RETRACT_DIST", 1.0, minval=1)
+        sample_count = params.get_int("SAMPLES", 5, minval=3)
         position = self._toolhead.get_position()
 
         logger.info(
@@ -75,12 +77,10 @@ class TouchAccuracyMacro(Macro):
         mad = compute_mad(measurements)
 
         logger.info(
-            """
-            touch accuracy results:\n
-            maximum %.6f, minimum %.6f, range %.6f,\n
-            average %.6f, median %.6f,\n
-            standard deviation %.6f, median absolute deviation %.6f
-            """,
+            "touch accuracy results:\n"
+            "maximum %.6f, minimum %.6f, range %.6f,\n"
+            "average %.6f, median %.6f,\n"
+            "standard deviation %.6f, median absolute deviation %.6f",
             max_value,
             min_value,
             range_value,
@@ -91,16 +91,6 @@ class TouchAccuracyMacro(Macro):
         )
 
 
-class _FakeHomingState(HomingState):
-    @override
-    def is_homing_z(self) -> bool:
-        return True
-
-    @override
-    def set_z_homed_position(self, position: float) -> None:
-        pass
-
-
 @final
 class TouchHomeMacro(Macro):
     description = "Touch the bed to home Z axis"
@@ -109,14 +99,20 @@ class TouchHomeMacro(Macro):
         self,
         probe: TouchMode,
         toolhead: Toolhead,
+        *,
         home_position: tuple[float, float],
+        travel_speed: float,
+        random_radius: float,
     ) -> None:
         self._probe = probe
         self._toolhead = toolhead
         self._home_position = home_position
+        self._travel_speed = travel_speed
+        self._random_radius = random_radius
 
     @override
     def run(self, params: MacroParams) -> None:
+        random_radius = params.get_float("EXPERIMENTAL_RANDOM_RADIUS", default=self._random_radius, minval=0)
         if not self._toolhead.is_homed("x") or not self._toolhead.is_homed("y"):
             msg = "Must home x and y before touch homing"
             raise RuntimeError(msg)
@@ -133,10 +129,11 @@ class TouchHomeMacro(Macro):
             z=pos.z + 2,
             speed=5,
         )
+        home_x, home_y = self._get_homing_position(random_radius)
         self._toolhead.move(
-            x=self._home_position[0],
-            y=self._home_position[1],
-            speed=50,
+            x=home_x,
+            y=home_y,
+            speed=self._travel_speed,
         )
         self._toolhead.wait_moves()
 
@@ -146,13 +143,28 @@ class TouchHomeMacro(Macro):
             if forced_z:
                 self._toolhead.clear_z_homing_state()
 
+        self._toolhead.z_home_end(self._probe)
         pos = self._toolhead.get_position()
         self._toolhead.set_z_position(pos.z - trigger_pos)
-        # Simulate home end to update last homing time
-        self._probe.on_home_end(_FakeHomingState())
+
         logger.info(
             "Touch home at (%.3f,%.3f) adjusted z by %.3f",
             pos.x,
             pos.y,
             trigger_pos,
         )
+
+    def _get_homing_position(self, random_radius: float) -> tuple[float, float]:
+        center_x, center_y = self._home_position
+        u1 = random()  # [0, 1)
+        u2 = random()  # [0, 1)
+
+        # Polar coordinates with square root for uniform area distribution
+        radius = random_radius * math.sqrt(u1)
+        angle = 2 * math.pi * u2
+
+        # Convert to Cartesian coordinates
+        x = center_x + radius * math.cos(angle)
+        y = center_y + radius * math.sin(angle)
+
+        return (x, y)
