@@ -5,7 +5,7 @@ from typing import TYPE_CHECKING, Protocol
 if TYPE_CHECKING:
     from cartographer.interfaces.configuration import Configuration
     from cartographer.interfaces.multiprocessing import TaskExecutor
-    from cartographer.interfaces.printer import Mcu, Toolhead
+    from cartographer.interfaces.printer import GCodeDispatch, Mcu, Toolhead
     from cartographer.macros.axis_twist_compensation import AxisTwistCompensationAdapter
     from cartographer.macros.bed_mesh.interfaces import BedMeshAdapter
 
@@ -17,3 +17,4 @@ class Adapters(Protocol):
     axis_twist_compensation: AxisTwistCompensationAdapter | None
     bed_mesh: BedMeshAdapter
     task_executor: TaskExecutor
+    gcode: GCodeDispatch
