@@ -12,4 +12,4 @@ class Integrator(Protocol):
     def register_cartographer(self, cartographer: PrinterCartographer) -> None: ...
     def register_macro(self, registration: MacroRegistration) -> None: ...
     def register_endstop_pin(self, chip_name: str, pin: str, endstop: Endstop) -> None: ...
-    def register_temperature_sensor_factories(self) -> None: ...
+    def register_coil_temperature_sensor(self) -> None: ...
