@@ -59,12 +59,17 @@ class Session(Generic[T]):
 
 
 class Stream(ABC, Generic[T]):
-    def __init__(self, smoothing_fn: Callable[[T], T] | None = None):
-        """Initializes a stream with optional smoothing function."""
-        self.smoothing_fn: Callable[[T], T] | None = smoothing_fn
+    def __init__(self):
+        """Initializes a stream."""
         self.sessions: set[Session[T]] = set()
         self.callbacks: set[Callable[[T], None]] = set()
 
+    _last_item: T | None = None
+
+    @property
+    def last_item(self) -> T | None:
+        return self._last_item
+
     @abstractmethod
     def condition(self) -> Condition: ...
 
@@ -91,9 +96,7 @@ class Stream(ABC, Generic[T]):
 
     def add_item(self, item: T):
         """Pushes the item to all active sessions."""
-
-        if self.smoothing_fn is not None:
-            item = self.smoothing_fn(item)
+        self._last_item = item
 
         for session in self.sessions:
             session.add_item(item)
