@@ -20,7 +20,7 @@ def configure_probe(probe: Probe, config: Configuration) -> None:
     poly = Polynomial([0, 1])
     poly = cast("Polynomial", poly.convert(domain=[0, 20]))
 
-    model = ScanModelConfiguration("test_scan", poly.coef, poly.domain, z_offset=0)
+    model = ScanModelConfiguration("test_scan", poly.coef, poly.domain, z_offset=0, reference_temperature=40)
     config.save_scan_model(model)
     probe.scan.load_model(model.name)
 
@@ -29,14 +29,12 @@ def sample(
     frequency: float = 1,
     time: float = 0,
     position: Position | None = None,
-    velocity: float | None = 0,
     temperature: float = 0,
 ):
     return Sample(
         frequency=1 / frequency,
         time=time,
         position=position,
-        velocity=velocity,
         temperature=temperature,
     )
 
@@ -130,8 +128,8 @@ def test_endstop_is_not_triggered(mocker: MockerFixture, probe: Probe):
 
 def test_probe_does_homing_move(mocker: MockerFixture, probe: Probe, toolhead: Toolhead):
     probe.scan.measure_distance = mocker.Mock(return_value=3)
-    toolhead.z_homing_move = mocker.Mock(return_value=2)
+    toolhead.z_probing_move = mocker.Mock(return_value=2)
 
     _ = probe.scan.perform_probe()
 
-    assert toolhead.z_homing_move.mock_calls == [mocker.call(probe.scan, speed=mocker.ANY)]
+    assert toolhead.z_probing_move.mock_calls == [mocker.call(probe.scan, speed=mocker.ANY)]
